import { View, Input, Text } from '@tarojs/components'
import { FC, useMemo, useState } from 'react'
import LinkBlueTooth from '../components/bluetooth/LinkBlueTooth'
import SelectProduct from '@/components/selectProduct/index'
import styles from './index.module.scss'
import ColorCard from './components/ColorCard'
import IconFont from '@/components/iconfont/iconfont'
import { ColorListApi, ColorDetailedApi, TextureSaveApi, ColorSamplingSaveApi } from '@/api/index'
import { formatHashTag } from '@/common/format'
// 颜色取样
const TakeColor: FC = () => {
  const { state, fetchData } = ColorListApi()
  const { state: detail, fetchData: detailFetchData } = ColorDetailedApi()
  const { state: textureSaveData, fetchData: textureSaveFetchData } = TextureSaveApi()
  const { state: saveData, fetchData: saveFetchData, success: saveSuccess } = ColorSamplingSaveApi()

  const [searchValue, setSearchValue] = useState('')

  const selectInput = async (event) => {
    // if (event) {
    //   selectedProduct.value = event
    //   await fetchData({ id: event.id })
    //   data.value?.list.map((item, index) => {
    //     item.currnetRgb = item.rgb
    //     item.currentLab = item.lab
    //     item.sampling = !(item.currentLab?.l == 0 && item.currentLab?.a == 0 && item.currentLab?.b == 0)
    //     item.moveBorder = 0
    //     item.key = index
    //   })
    //   detailFetchData({ id: event.id })
    // } else {
    //   data.value.list = []
    // }
  }
  const clearSearchValue = () => {
    setSearchValue('')
  }

  const handleTransfSearch = (bool: boolean) => {
    setShowScreen(bool)
  }
  const handlePrViewRgb = (event) => {
    setLabPreview(event)
    setShowLabPreview(true)
  }
  const handleTakeColor = () => {}

  const listData = useMemo(() => {
    return state.data?.list?.filter((item) => {
      if (searchValue) {
        return formatHashTag(item.product_color_name, item.product_color_code)!.includes(searchValue)
      }
      return true
    })
  }, [state])

  const [showScreen, setShowScreen] = useState(false)

  const onSearchInput = (event) => {
    const current = event.detail.value
    setSearchValue(current)
  }
  // 重置
  const handleReset = () => {}

  // 提交
  const handleSubmit = () => {}

  const [labPreview, setLabPreview] = useState({
    currnetRgb: {
      r: 0,
      g: 0,
      b: 0,
    },
  })

  const [showLabPreview, setShowLabPreview] = useState(false)

  return (
    <>
      <View className={styles.card}>
        <LinkBlueTooth />
        <SelectProduct onSelect={selectInput} />
      </View>
      <View className={styles['list-box']}>
        <View className={styles['lb-title']}>
          <Text>颜色列表（{listData?.length ?? 0}）</Text>
          <View className={styles['lb-t-serach']}>
            {showScreen ? (
              <View className={styles['lb-t-search-content']}>
                <View>
                  <Input value={searchValue} type='text' onInput={onSearchInput} placeholder='筛选颜色或颜色编号' />
                  <View onClick={clearSearchValue} className={styles['lb-t-sc-clear']}>
                    {searchValue.length > 0 && <IconFont name='icon-guanbi' size={56}></IconFont>}
                  </View>
                </View>
                <Text onClick={() => handleTransfSearch(false)}>取消</Text>
              </View>
            ) : (
              <View onClick={() => handleTransfSearch(true)}>
                <IconFont name='icon-sousuo' size={56}></IconFont>
              </View>
            )}
          </View>
        </View>
        {listData ? (
          listData.map((item, index) => {
            return <ColorCard onPreviewRgb={handlePrViewRgb} onTakeColor={handleTakeColor} key={index} item={item} index={item.key} />
          })
        ) : (
          <View className={styles['not-list']}>-请取色-</View>
        )}
      </View>
      <View className={styles['fixedBottom-container']}>
        <View onClick={handleReset}>重置</View>
        <View onClick={handleSubmit} className={styles['fb-confirm']}>
          提交
        </View>
      </View>
      {showLabPreview && (
        <View catchMove onClick={() => setShowLabPreview(false)} className={styles['lab-view']}>
          <View
            style={{
              backgroundColor: `rgb(
            ${labPreview?.currnetRgb?.r},
            ${labPreview?.currnetRgb?.g},
            ${labPreview?.currnetRgb?.b}
        )`,
            }}></View>
        </View>
      )}
    </>
  )
}

export default TakeColor
