
import { ScrollView, View, Image } from '@tarojs/components'
import { memo, useCallback, useEffect, useMemo, useState, useRef } from 'react'
import styles from './index.module.scss'
import classnames from 'classnames'
import BottomBtns from '@/components/BottomBtns'
import { formatPriceDiv, formatImgUrl } from '@/common/format'
import Taro from '@tarojs/taro'
import Popup from '@/components/popup'
import useCheckAuthorize from '@/use/useCheckAuthorize'
import { alert } from '@/common/common'

interface Props {
    showPopup: true | false,
    popupClose?: () => void,
    obj: {
        wait_pay_amount?: number | string,
        actual_amount?: number | string,
        total_sale_price?: number | string,
        should_collect_order_id?: number | string,
        pre_collect_order_id?: number | string,
        status?: number | string,
    },
    showSide?: boolean,
    list?: any[],
    clickItem?: (any) => void,
    handsurePay?: (any) => void,
    title: string,
    picUrl?: string
}

export default memo((props: Props) => {
    const {
        showSide = true,
        showPopup = false,
        popupClose,
        obj = {
            wait_pay_amount: '',
            actual_amount: '',
            total_sale_price: ''
        },
        clickItem,
        handsurePay,
        list = [],
        title = '待支付款项',
        picUrl = ''
    } = props

    const fileData = useRef({
        filePath: '',
        base64: '',
    })

    //预览图片
    const showImage = () => {
        const time = new Date().valueOf()
        const [, format, bodyData] = /data:image\/(\w+);base64,(.*)/.exec(picUrl) || []
        let filePath = Taro.env.USER_DATA_PATH + '/img' + time + '.' + format
        fileData.current.filePath = filePath
        fileData.current.base64 = bodyData
        const save = Taro.getFileSystemManager()
        save.writeFile({
            filePath: fileData.current.filePath,
            data: fileData.current.base64,
            encoding: 'base64',
        })
        Taro.previewImage({
            current: fileData.current.filePath, // 当前显示
            urls: [fileData.current.filePath], // 需要预览的图片http链接列表
        })
    }


    //检查是否开启保存图片权限
    const { check } = useCheckAuthorize({ scope: 'scope.writePhotosAlbum', msg: '您没授权，无法保存图片' })
    const saveImageCheck = async () => {
        const res = await check()
        res && saveImage()
    }

    //保存图片
    const saveImage = () => {
        const time = new Date().valueOf()
        const [, format, bodyData] = /data:image\/(\w+);base64,(.*)/.exec(picUrl) || []
        let filePath = Taro.env.USER_DATA_PATH + '/img' + time + '.' + format
        fileData.current.filePath = filePath
        fileData.current.base64 = bodyData
        const save = Taro.getFileSystemManager()
        save.writeFile({
            filePath: fileData.current.filePath,
            data: fileData.current.base64,
            encoding: 'base64',
        })
        alert.loading('正在保存图片')
        Taro.saveImageToPhotosAlbum({
            filePath: fileData.current.filePath,
            success: function () {
                alert.success('图片保存成功')
            },
            fail: function (err) {
                console.log('err::', err)
            },
        })
    }

    return (
        <View className={styles.popupBox}>
            <Popup show={showPopup} title={title} onClose={() => popupClose?.()}>
                {
                    showSide &&
                    <View className={styles.contBox}>
                        <View className={styles.topMoney}>
                            ￥{formatPriceDiv(obj.wait_pay_amount)}
                        </View>
                        <View className={styles.itemMoney}>
                            <View className={styles.leftFont}>
                                订单金额
                            </View>
                            <View className={styles.rightFont}>
                                ￥{formatPriceDiv(obj.total_sale_price)}
                            </View>
                        </View>
                        <View className={styles.itemMoney}>
                            <View className={styles.leftFont}>
                                已付金额
                            </View>
                            <View className={styles.rightFont}>
                                ￥{formatPriceDiv(obj.actual_amount)}
                            </View>
                        </View>
                        <View className={styles.line}></View>
                        {
                            list.map((item, index) => {
                                return (
                                    <View className={styles.itemBox} key={index} onClick={() => clickItem?.(item)}>
                                        <View className={styles.leftItem}>
                                            <View className={styles.leftCrile}>
                                                <View className={classnames('iconfont', item.iconfont, styles.lujing)}></View>
                                            </View>
                                            <View className={styles.rightLeft}>
                                                <View className={styles.title}>{item.name}</View>
                                                {
                                                    item.fonts && <View className={styles.nums}>{item.fonts}{
                                                        item.money !== "" ? "￥" : ""
                                                    }{item.money}</View>
                                                }
                                            </View>
                                        </View>
                                        {
                                            item.name !== '扫码支付' && item.name !== '线下汇款' &&
                                            <View className={item.checked ? styles.activeChecked : styles.checkYuan}>
                                                <View className={classnames('iconfont', 'icon-lujing', styles.gou)}></View>
                                            </View>
                                        }
                                        {
                                            (item.name === '扫码支付' || item.name === '线下汇款') &&
                                            <View className={classnames('iconfont', 'icon-chakanquanbukehu', styles.chakanquanbukehu)}></View>
                                        }
                                    </View>
                                )
                            })
                        }

                    </View>

                }
                {
                    showSide && <View className={styles.sure} onClick={() => handsurePay?.(props?.obj)}>确认交易</View>
                }
                {
                    !showSide &&
                    <ScrollView enhanced scrollY style={{ height: '700rpx', marginLeft: '24rpx' }}>
                        <View className={styles.pic}>
                            <Image lazyLoad mode='widthFix' style={{ width: '100%', height: '100%' }} src={picUrl} onClick={() => showImage()}></Image>
                        </View>
                    </ScrollView>

                }
                {
                    !showSide && <View className={styles.sure} onClick={() => saveImageCheck()}>保存图片</View>
                }
            </Popup >
        </View >
    )
})