import { View, Text, Image } from '@tarojs/components'
import MCheckbox from '@/components/checkbox'
import Counter from '@/components/counter'
import { FC, memo, ReactNode, useCallback, useEffect, useState } from 'react'
import classnames from 'classnames'
import styles from './index.module.scss'
import { debounce } from '@/common/util'
import { formatImgUrl, formatPriceDiv } from '@/common/format'
import { EnumSaleMode } from '@/common/Enumerate'
import { useNeedMemoCallback } from '@/use/useCommon'
import { selectList } from '../../config'
import { useShoppingContext, useWatch } from '../../context'
type PropsType = {
  purchaserId: number
  itemData: Record<string, any> & object
  orderType: EnumSaleMode
}

// 注意：如果在表单控件内部使用 useWatch，由于是直接从Context中取值，memo也会直接失去作用。

const ColorKindItem: FC<PropsType> = memo(
  (props) => {
    const { purchaserId, itemData, orderType = EnumSaleMode.Bulk } = props
    console.log('重新渲染 ColorKindItem', itemData.id, orderType, purchaserId)
    const { setChangedCheckbox, colorStore } = useShoppingContext()
    // @ts-ignore
    const { checked } = useWatch(purchaserId, itemData?.id)

    //格式化金额
    const formatPrice = useCallback((price) => {
      return Number(formatPriceDiv(price))
    }, [])

    //格式化数量
    const formatCount = useCallback((itemData) => {
      return itemData.sale_mode == EnumSaleMode.Bulk ? itemData.roll : itemData.length / 100
    }, [])

    //格式化单位
    const formatUnit = useCallback((itemData) => {
      return itemData.sale_mode == EnumSaleMode.Bulk ? '条' : '米'
    }, [])

    const handleSelect = () => {
      console.log('handleSelect')
      setChangedCheckbox({
        purchaserId: purchaserId,
        goodsKind: { [itemData.id]: { ...colorStore[purchaserId].goodsKind?.[itemData.id]!, checked: true } },
        checked: colorStore[purchaserId].checked,
      })
    }
    const handleClose = () => {
      setChangedCheckbox({
        purchaserId: purchaserId,
        goodsKind: { [itemData.id]: { ...colorStore[purchaserId].goodsKind?.[itemData.id]!, checked: false } },
        checked: colorStore[purchaserId].checked,
      })
    }

    const getInputValue = debounce(async (num, itemData) => {
      if (itemData.sale_mode === EnumSaleMode.Bulk) {
        itemData.roll = num
      } else {
        itemData.length = num
      }
    }, 300)

    return (
      <MCheckbox
        status={checked}
        onSelect={handleSelect}
        onClose={handleClose}
        customClassName={classnames(styles.checkbox, checked ? styles.selected : '')}
        customTextClass={styles.colorKindItem}>
        <View className={styles['colorKindItem__left']}>
          <Image className={styles['colorKindItem__left--image']} mode='aspectFill' src={formatImgUrl(itemData.product_color_texture_url)}></Image>
        </View>
        <View className={styles['colorKindItem__center']}>
          <Text className={styles['colorKindItem__center--title']}>
            {itemData.product_code}# {itemData.product_name}
          </Text>
          <View className={styles['colorKindItem__center--detail']}>
            <Text className={styles['colorKindItem__center--ID']}>{itemData.product_color_code}</Text>
            <Text className={styles['colorKindItem__center--description']}>{itemData.product_color_name}</Text>
          </View>
        </View>
        <View className={styles['colorKindItem__right']}>
          <View className={styles['colorKindItem__right--price']}>￥ {formatPrice(itemData.sale_price)}/kg</View>
          <View className={styles['colorKindItem__right--counter']}>
            <Counter
              onBlue={(e) => getInputValue(e, itemData)}
              defaultNum={formatCount(itemData)}
              step={selectList[orderType].step}
              digits={selectList[orderType].digits}
              onClickBtn={(e) => getInputValue(e, itemData)}
              unit={formatUnit(itemData)}
              minNum={selectList[orderType].minNum}
              maxNum={selectList[orderType].maxNum}
            />
          </View>
        </View>
      </MCheckbox>
    )
  },
  (preProp, nextProp) => {
    const stringifyPreProp = JSON.stringify(preProp.itemData)
    const stringifyNextProp = JSON.stringify(nextProp.itemData)
    console.log('memo==>', preProp, nextProp)
    let needMemoized = true
    if (preProp.purchaserId !== nextProp.purchaserId) {
      needMemoized = false
    }
    if (preProp.orderType !== nextProp.orderType) {
      needMemoized = false
    }
    if (stringifyPreProp !== stringifyNextProp) {
      needMemoized = false
    }
    return needMemoized
  },
)
export default ColorKindItem
